@@ -92,7 +92,8 @@ def assignment_command(config, canvas, args):
       if "less" in pager and ("-R" in pager or "-r" in pager):
         styles = True
       with console.pager(styles=styles, links=True):
-        console.print(rich.markdown.Markdown(output))
+        console.print(rich.markdown.Markdown(output,
+                                             code_theme="manni"))
     else:
       print(output)
 def format_assignment(assignment):
