@@ -127,14 +127,21 @@ def filter_submissions(submission_list, user_list):
         yield submission
         break
 def format_submission_short(submission):
-  return [submission.assignment.course.course_code, submission.assignment.name,
-    submission.user.name, submission.grade,
-    submission.submitted_at, submission.graded_at]
-
+  return [
+    submission.assignment.course.course_code,
+    submission.assignment.name,
+    submission.user.name,
+    submission.grade, submission.submitted_at, submission.graded_at
+  ]
 def format_submission_short_unique(submission):
-  return [submission.assignment.course.course_code, submission.assignment.name,
-    submission.user.login_id, submission.grade,
-    submission.submitted_at, submission.graded_at]
+  uid = users.get_uid(submission.user)
+
+  return [
+    submission.assignment.course.course_code,
+    submission.assignment.name,
+    uid,
+    submission.grade, submission.submitted_at, submission.graded_at
+  ]
 def format_submission(submission):
   """Formats submission for printing to stdout"""
   student = submission.assignment.course.get_user(submission.user_id)
